==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QMessageLogContext_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qlogging.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QMessageLogContext(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMessageLogContext")
    QMessageLogContext *_ptr = reinterpret_cast<QMessageLogContext *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QMessageLogContext()
void __qt_construct_QMessageLogContext_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMessageLogContext()")
    Q_UNUSED(__java_arguments)
    QMessageLogContext *__qt_this = new(__qtjambi_ptr) QMessageLogContext();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QMessageLogContext
void __qt_destruct_QMessageLogContext(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMessageLogContext")
    reinterpret_cast<QMessageLogContext*>(ptr)->~QMessageLogContext();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QMessageLogContext::QMessageLogContext()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageLogContext_initialize_1native__Lio_qt_core_QMessageLogContext_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMessageLogContext::QMessageLogContext()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMessageLogContext_0, sizeof(QMessageLogContext), typeid(QMessageLogContext), false, &deleter_QMessageLogContext, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageLogContext_category_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMessageLogContext *__qt_this = QtJambiAPI::objectFromNativeId<QMessageLogContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const char*  __qt_value = __qt_this->category;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageLogContext_file_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMessageLogContext *__qt_this = QtJambiAPI::objectFromNativeId<QMessageLogContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const char*  __qt_value = __qt_this->file;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageLogContext_function_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMessageLogContext *__qt_this = QtJambiAPI::objectFromNativeId<QMessageLogContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const char*  __qt_value = __qt_this->function;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageLogContext_line_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMessageLogContext *__qt_this = QtJambiAPI::objectFromNativeId<QMessageLogContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->line;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMessageLogContext(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QMessageLogContext>("QMessageLogContext", "io/qt/core/QMessageLogContext");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QMessageLogContext, {
        ConstructorInfo(&__qt_construct_QMessageLogContext_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMessageLogContext);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QMessageLogContext_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qlogging.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QMessageLogContext(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QMessageLogContext")
    QMessageLogContext *_ptr = reinterpret_cast<QMessageLogContext *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QMessageLogContext()
void __qt_construct_QMessageLogContext(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QMessageLogContext()")
    Q_UNUSED(__java_arguments)
    QMessageLogContext *__qt_this = new(__qtjambi_ptr) QMessageLogContext();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QMessageLogContext::QMessageLogContext()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageLogContext_initialize_1native__Lio_qt_core_QMessageLogContext_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QMessageLogContext::QMessageLogContext()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QMessageLogContext, sizeof(QMessageLogContext), typeid(QMessageLogContext), 0, false, &deleter_QMessageLogContext, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QMessageLogContext
void __qt_destruct_QMessageLogContext(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QMessageLogContext")
    reinterpret_cast<QMessageLogContext*>(ptr)->~QMessageLogContext();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageLogContext_category_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMessageLogContext *__qt_this = QtJambiAPI::objectFromNativeId<QMessageLogContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const char*  __qt_value = __qt_this->category;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageLogContext_file_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMessageLogContext *__qt_this = QtJambiAPI::objectFromNativeId<QMessageLogContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const char*  __qt_value = __qt_this->file;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageLogContext_function_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMessageLogContext *__qt_this = QtJambiAPI::objectFromNativeId<QMessageLogContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const char*  __qt_value = __qt_this->function;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QMessageLogContext_line_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QMessageLogContext *__qt_this = QtJambiAPI::objectFromNativeId<QMessageLogContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->line;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QMessageLogContext(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QMessageLogContext>("QMessageLogContext", "io/qt/core/QMessageLogContext");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QMessageLogContext, {
        ConstructorInfo(&__qt_construct_QMessageLogContext, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QMessageLogContext);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
